@@ -30,15 +30,15 @@ pub fn run_app(version: Version) -> Result<(), ExitCode> {
     let (bin_name, app_matches) = cli::get_bin_name_and_matches(&version);
     match app_matches.subcommand() {
         (cli::CMD_INIT, Some(matches)) => {
-            return subcommand::init(Setup::init(&matches)?);
+            return subcommand::init(Setup::init(matches)?);
         }
         (cli::CMD_LIST_HASHES, Some(matches)) => {
-            return subcommand::list_hashes(Setup::root_dir_from_matches(&matches)?, matches);
+            return subcommand::list_hashes(Setup::root_dir_from_matches(matches)?, matches);
         }
         (cli::CMD_PEERID, Some(matches)) => match matches.subcommand() {
-            (cli::CMD_GEN_SECRET, Some(matches)) => return Setup::gen(&matches),
+            (cli::CMD_GEN_SECRET, Some(matches)) => return Setup::gen(matches),
             (cli::CMD_FROM_SECRET, Some(matches)) => {
-                return subcommand::peer_id(Setup::peer_id(&matches)?);
+                return subcommand::peer_id(Setup::peer_id(matches)?);
             }
             _ => {}
         },
@@ -58,15 +58,15 @@ pub fn run_app(version: Version) -> Result<(), ExitCode> {
     raise_fd_limit();
 
     let ret = match cmd {
-        cli::CMD_RUN => subcommand::run(setup.run(&matches)?, version, handle),
-        cli::CMD_MINER => subcommand::miner(setup.miner(&matches)?, handle),
-        cli::CMD_REPLAY => subcommand::replay(setup.replay(&matches)?, handle),
-        cli::CMD_EXPORT => subcommand::export(setup.export(&matches)?, handle),
-        cli::CMD_IMPORT => subcommand::import(setup.import(&matches)?, handle),
-        cli::CMD_STATS => subcommand::stats(setup.stats(&matches)?, handle),
-        cli::CMD_RESET_DATA => subcommand::reset_data(setup.reset_data(&matches)?),
-        cli::CMD_MIGRATE => subcommand::migrate(setup.migrate(&matches)?),
-        cli::CMD_DB_REPAIR => subcommand::db_repair(setup.db_repair(&matches)?),
+        cli::CMD_RUN => subcommand::run(setup.run(matches)?, version, handle),
+        cli::CMD_MINER => subcommand::miner(setup.miner(matches)?, handle),
+        cli::CMD_REPLAY => subcommand::replay(setup.replay(matches)?, handle),
+        cli::CMD_EXPORT => subcommand::export(setup.export(matches)?, handle),
+        cli::CMD_IMPORT => subcommand::import(setup.import(matches)?, handle),
+        cli::CMD_STATS => subcommand::stats(setup.stats(matches)?, handle),
+        cli::CMD_RESET_DATA => subcommand::reset_data(setup.reset_data(matches)?),
+        cli::CMD_MIGRATE => subcommand::migrate(setup.migrate(matches)?),
+        cli::CMD_DB_REPAIR => subcommand::db_repair(setup.db_repair(matches)?),
         _ => unreachable!(),
     };
 
