@@ -5,7 +5,6 @@ use ckb_types::{packed::CellOutput, prelude::*, H256};
 use clap::ArgMatches;
 use serde::{Deserialize, Serialize};
 use std::collections::BTreeMap;
-use std::convert::{TryFrom, TryInto};
 use std::path::PathBuf;
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
@@ -130,7 +129,7 @@ pub fn list_hashes(root_dir: PathBuf, matches: &ArgMatches<'_>) -> Result<(), Ex
             resource = Resource::bundled_ckb_config();
         }
 
-        let mut config: CKBAppConfig = toml::from_slice(&resource.get()?)?;
+        let mut config = CKBAppConfig::load_from_slice(&resource.get()?)?;
         config.chain.spec.absolutize(&root_dir);
         let chain_spec = ChainSpec::load_from(&config.chain.spec).map_err(to_config_error)?;
         let spec_name = chain_spec.name.clone();
@@ -154,6 +153,6 @@ pub fn list_hashes(root_dir: PathBuf, matches: &ArgMatches<'_>) -> Result<(), Ex
 }
 
 fn to_config_error(err: Box<dyn std::error::Error>) -> ExitCode {
-    eprintln!("{:?}", err);
+    eprintln!("ERROR: {}", err);
     ExitCode::Config
 }
